@@ -1,201 +1,11 @@
 # Net::Netrc.pm
 #
-# Copyright (c) 1995-1998 Graham Barr <gbarr@pobox.com>. All rights reserved.
-# This program is free software; you can redistribute it and/or
+# Copyright (c) 1995 Graham Barr <Graham.Barr@tiuk.ti.com>. All rights
+# reserved. This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 
 package Net::Netrc;
 
-use Carp;
-use strict;
-use FileHandle;
-use vars qw($VERSION $TESTING);
-
-$VERSION = "2.13_01";
-
-my %netrc = ();
-
-
-sub _readrc {
-  my $host = shift;
-  my ($home, $file);
-
-  if ($^O eq "MacOS") {
-    $home = $ENV{HOME} || `pwd`;
-    chomp($home);
-    $file = ($home =~ /:$/ ? $home . "netrc" : $home . ":netrc");
-  }
-  else {
-
-    # Some OS's don't have `getpwuid', so we default to $ENV{HOME}
-    $home = eval { (getpwuid($>))[7] } || $ENV{HOME};
-    $home ||= $ENV{HOMEDRIVE} . ($ENV{HOMEPATH} || '') if defined $ENV{HOMEDRIVE};
-    if (-e $home . "/.netrc") {
-      $file = $home . "/.netrc";
-    }
-    elsif (-e $home . "/_netrc") {
-      $file = $home . "/_netrc";
-    }
-    else {
-      return unless $TESTING;
-    }
-  }
-
-  my ($login, $pass, $acct) = (undef, undef, undef);
-  my $fh;
-  local $_;
-
-  $netrc{default} = undef;
-
-  # OS/2 and Win32 do not handle stat in a way compatable with this check :-(
-  unless ($^O eq 'os2'
-    || $^O eq 'MSWin32'
-    || $^O eq 'MacOS'
-    || $^O =~ /^cygwin/)
-  {
-    my @stat = stat($file);
-
-    if (@stat) {
-      if ($stat[2] & 077) {
-        carp "Bad permissions: $file";
-        return;
-      }
-      if ($stat[4] != $<) {
-        carp "Not owner: $file";
-        return;
-      }
-    }
-  }
-
-  if ($fh = FileHandle->new($file, "r")) {
-    my ($mach, $macdef, $tok, @tok) = (0, 0);
-
-    while (<$fh>) {
-      undef $macdef if /\A\n\Z/;
-
-      if ($macdef) {
-        push(@$macdef, $_);
-        next;
-      }
-
-      s/^\s*//;
-      chomp;
-
-      while (length && s/^("((?:[^"]+|\\.)*)"|((?:[^\\\s]+|\\.)*))\s*//) {
-        (my $tok = $+) =~ s/\\(.)/$1/g;
-        push(@tok, $tok);
-      }
-
-    TOKEN:
-      while (@tok) {
-        if ($tok[0] eq "default") {
-          shift(@tok);
-          $mach = bless {};
-          $netrc{default} = [$mach];
-
-          next TOKEN;
-        }
-
-        last TOKEN
-          unless @tok > 1;
-
-        $tok = shift(@tok);
-
-        if ($tok eq "machine") {
-          my $host = shift @tok;
-          $mach = bless {machine => $host};
-
-          $netrc{$host} = []
-            unless exists($netrc{$host});
-          push(@{$netrc{$host}}, $mach);
-        }
-        elsif ($tok =~ /^(login|password|account)$/) {
-          next TOKEN unless $mach;
-          my $value = shift @tok;
-
-          # Following line added by rmerrell to remove '/' escape char in .netrc
-          $value =~ s/\/\\/\\/g;
-          $mach->{$1} = $value;
-        }
-        elsif ($tok eq "macdef") {
-          next TOKEN unless $mach;
-          my $value = shift @tok;
-          $mach->{macdef} = {}
-            unless exists $mach->{macdef};
-          $macdef = $mach->{machdef}{$value} = [];
-        }
-      }
-    }
-    $fh->close();
-  }
-}
-
-
-sub lookup {
-  my ($pkg, $mach, $login) = @_;
-
-  _readrc()
-    unless exists $netrc{default};
-
-  $mach ||= 'default';
-  undef $login
-    if $mach eq 'default';
-
-  if (exists $netrc{$mach}) {
-    if (defined $login) {
-      my $m;
-      foreach $m (@{$netrc{$mach}}) {
-        return $m
-          if (exists $m->{login} && $m->{login} eq $login);
-      }
-      return undef;
-    }
-    return $netrc{$mach}->[0];
-  }
-
-  return $netrc{default}->[0]
-    if defined $netrc{default};
-
-  return undef;
-}
-
-
-sub login {
-  my $me = shift;
-
-  exists $me->{login}
-    ? $me->{login}
-    : undef;
-}
-
-
-sub account {
-  my $me = shift;
-
-  exists $me->{account}
-    ? $me->{account}
-    : undef;
-}
-
-
-sub password {
-  my $me = shift;
-
-  exists $me->{password}
-    ? $me->{password}
-    : undef;
-}
-
-
-sub lpa {
-  my $me = shift;
-  ($me->login, $me->password, $me->account);
-}
-
-1;
-
-__END__
-
 =head1 NAME
 
 Net::Netrc - OO interface to users netrc file
@@ -203,7 +13,7 @@ Net::Netrc - OO interface to users netrc file
 =head1 SYNOPSIS
 
     use Net::Netrc;
-
+    
     $mach = Net::Netrc->lookup('some.machine');
     $login = $mach->login;
     ($login, $password, $account) = $mach->lpa;
@@ -275,7 +85,7 @@ with I<ftp>.
 
 The constructor for a C<Net::Netrc> object is not called new as it does not
 really create a new object. But instead is called C<lookup> as this is
-essentially what it does.
+essentially what it deos.
 
 =over 4
 
@@ -288,9 +98,6 @@ the first entry in the .netrc file for C<MACHINE> will be returned.
 If a matching entry cannot be found, and a default entry exists, then a
 reference to the default entry is returned.
 
-If there is no matching entry found and there is no default defined, or
-no .netrc file is found, then C<undef> is returned.
-
 =back
 
 =head1 METHODS
@@ -311,13 +118,17 @@ Return the account information for the netrc entry
 
 =item lpa ()
 
-Return a list of login, password and account information for the netrc entry
+Return a list of login, password and account information fir the netrc entry
 
 =back
 
 =head1 AUTHOR
 
-Graham Barr <gbarr@pobox.com>
+Graham Barr <Graham.Barr@tiuk.ti.com>
+
+=head1 REVISION
+
+$Revision: 2.1 $
 
 =head1 SEE ALSO
 
@@ -326,8 +137,180 @@ L<Net::Cmd>
 
 =head1 COPYRIGHT
 
-Copyright (c) 1995-1998 Graham Barr. All rights reserved.
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+Copyright (c) 1995 Graham Barr. All rights reserved. This program is free
+software; you can redistribute it and/or modify it under the same terms
+as Perl itself.
 
 =cut
+
+use Carp;
+use strict;
+use FileHandle;
+use vars qw($VERSION);
+
+$VERSION = sprintf("%d.%02d", q$Revision: 2.1 $ =~ /(\d+)\.(\d+)/);
+
+my %netrc = ();
+
+sub _readrc
+{
+ my $host = shift;
+
+ # Some OS's don't have `getpwuid', so we default to $ENV{HOME}
+ my $home = eval { (getpwuid($>))[7] } || $ENV{HOME};
+ my $file = $home . "/.netrc";
+
+ my($login,$pass,$acct) = (undef,undef,undef);
+ my $fh;
+ local $_;
+
+ $netrc{default} = undef;
+
+ # OS/2 does not handle stat in a way compatable with this check :-(
+ unless($^O eq 'os2')
+  { 
+   my @stat = stat($file);
+
+   if(@stat)
+    {
+     if($stat[2] & 077)
+      {
+       carp "Bad permissions: $file";
+       return;
+      }
+     if($stat[4] != $<)
+      {
+       carp "Not owner: $file";
+       return;
+      }
+    }
+  }
+
+ if($fh = FileHandle->new($file,"r"))
+  {
+   my($mach,$macdef,$tok,@tok) = (0,0);
+
+   while(<$fh>)
+    {
+     undef $macdef if /\A\n\Z/;
+
+     if($macdef)
+      {
+       push(@$macdef,$_);
+       next;
+      }
+
+     push(@tok, split(/[\s\n]+/, $_));
+
+TOKEN:
+     while(@tok)
+      {
+       if($tok[0] eq "default")
+        {
+         shift(@tok);
+         $mach = bless {};
+   	 $netrc{default} = [$mach];
+
+         next TOKEN;
+        }
+
+       last TOKEN
+            unless @tok > 1;
+
+       $tok = shift(@tok);
+
+       if($tok eq "machine")
+        {
+         my $host = shift @tok;
+         $mach = bless {machine => $mach};
+
+         $netrc{$host} = []
+            unless exists($netrc{$host});
+         push(@{$netrc{$host}}, $mach);
+        }
+       elsif($tok =~ /^(login|password|account)$/)
+        {
+         next TOKEN unless $mach;
+         my $value = shift @tok;
+         $mach->{$1} = $value;
+        }
+       elsif($tok eq "macdef")
+        {
+         next TOKEN unless $mach;
+         my $value = shift @tok;
+         $mach->{macdef} = {}
+            unless exists $mach->{macdef};
+         $macdef = $mach->{machdef}{$value} = [];
+        }
+      }
+    }
+   $fh->close();
+  }
+}
+
+sub lookup
+{
+ my($pkg,$mach,$login) = @_;
+
+ _readrc()
+    unless exists $netrc{default};
+
+ $mach ||= 'default';
+ undef $login
+    if $mach eq 'default';
+
+ if(exists $netrc{$mach})
+  {
+   if(defined $login)
+    {
+     my $m;
+     foreach $m (@{$netrc{$mach}})
+      {
+       return $m
+            if(exists $m->{login} && $m->{login} eq $login);
+      }
+     return undef;
+    }
+   return $netrc{$mach}->[0]
+  }
+
+ return $netrc{default}
+    if defined $netrc{default};
+
+ return undef;
+}
+
+sub login
+{
+ my $me = shift;
+
+ exists $me->{login}
+    ? $me->{login}
+    : undef;
+}
+
+sub account
+{
+ my $me = shift;
+
+ exists $me->{account}
+    ? $me->{account}
+    : undef;
+}
+
+sub password
+{
+ my $me = shift;
+
+ exists $me->{password}
+    ? $me->{password}
+    : undef;
+}
+
+sub lpa
+{
+ my $me = shift;
+ ($me->login, $me->password, $me->account);
+}
+
+1;
